@@ -1,14 +1,19 @@
 import numpy as np
-import math
 from mesh_to_sdf.pyrender_wrapper import render_normal_and_depth_buffers
 import pyrender
 from scipy.spatial.transform import Rotation
 from skimage import io
 
-def get_rotation_matrix(angle, axis='y'):
-    matrix = np.identity(4)
-    matrix[:3, :3] = Rotation.from_euler(axis, angle).as_dcm()
-    return matrix
+if hasattr(Rotation, "as_matrix"): # scipy>=1.4.0
+    def get_rotation_matrix(angle, axis='y'):
+        matrix = np.identity(4)
+        matrix[:3, :3] = Rotation.from_euler(axis, angle).as_matrix()
+        return matrix
+else: # scipy<1.4.0
+    def get_rotation_matrix(angle, axis='y'):
+        matrix = np.identity(4)
+        matrix[:3, :3] = Rotation.from_euler(axis, angle).as_dcm()
+        return matrix
 
 def get_camera_transform_looking_at_origin(rotation_y, rotation_x, camera_distance=2):
     camera_transform = np.identity(4)
@@ -21,9 +26,9 @@ def get_camera_transform_looking_at_origin(rotation_y, rotation_x, camera_distan
 def get_camera_transform(position, look_direction):
     camera_forward = -look_direction / np.linalg.norm(look_direction)
     camera_right = np.cross(camera_forward, np.array((0, 0, -1)))
-    if np.linalg.norm(camera_right) < 0.5:
-        camera_right = np.array((0, 1, 0))
+    camera_right /= np.linalg.norm(camera_right)
     camera_up = np.cross(camera_forward, camera_right)
+    camera_up /= np.linalg.norm(camera_up)
 
     rotation = np.identity(4)
     rotation[:3, 0] = camera_right
